'use strict';

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports['default'] = write_stats;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

// writes webpack-stats.json file, which contains assets' file paths

function write_stats(stats, options) {
	var _this = this;

	var _production_ = options.environment === 'production';
	var _development_ = options.environment === 'development';

	var output_path = this.options.output.publicPath;

	var json = stats.toJson();

	var output = {};

	// output.json = json

	var resolve_asset_path = function resolve_asset_path(asset_path) {
		// if (_development_)
		// {
		// 	// path.resolve doesn't work for Http protocol
		return _this.options.output.publicPath + asset_path
		// }
		// else
		// {
		// 	return path.resolve(this.options.output.path, asset_path)
		// }
		;
	};

	// // get assets by name and extensions
	function get_assets(name) {
		var extension = arguments.length <= 1 || arguments[1] === undefined ? 'js' : arguments[1];

		var chunk = json.assetsByChunkName[name];

		// a chunk could be a string or an array, so make sure it is an array
		if (!Array.isArray(chunk)) {
			chunk = [chunk];
		}

		return chunk
		// filter by extension
		.filter(function (name) {
			return _path2['default'].extname(name) === '.' + extension;
		}).map(function (name) {
			return resolve_asset_path(name);
		});
	}

	output.javascript = {};

	// output stats for all application javascript entry points
	_Object$keys(this.options.entry).forEach(function (chunk_name) {
		var entry = _this.options.entry[chunk_name];
		if (Array.isArray(entry)) {
			entry = entry[entry.length - 1];
		}

		output.javascript[entry] = get_assets(chunk_name, 'js')[0]
		// the second asset is usually a source map
		;
	});

	output.styles = {};

	if (_production_) {
		// output stats for all application css entry points
		// (it's how extract-text-plugin works in production)
		_Object$keys(this.options.entry).forEach(function (chunk_name) {
			var entry = _this.options.entry[chunk_name];
			if (Array.isArray(entry)) {
				entry = entry[entry.length - 1];
			}

			output.styles[entry] = get_assets(chunk_name, 'css')[0]
			// the second asset is usually a source map
			;
		});
	}

	// omit node_modules contents and internal webpack modules
	var modules = json.modules.filter(function (module) {
		return module.name.indexOf('./~/') !== 0 && module.name.indexOf('(webpack)') !== 0;
	});

	var default_filter = function default_filter(asset, regular_expression) {
		return regular_expression.test(asset.name);
	};

	_Object$keys(options.assets).forEach(function (asset_type) {
		var asset_description = options.assets[asset_type];

		var filter = (asset_description.filter || default_filter).bind(_this);
		var path_parser = asset_description.path_parser.bind(_this);

		if (!asset_description.path_parser) {
			throw new Error('path_parser required for asset type "' + asset_type + '"');
		}

		output[asset_type] = modules.filter(function (module) {
			return filter(module, options.regular_expressions[asset_type], options);
		}).reduce(function (set, module) {
			set[module.name] = path_parser(module, resolve_asset_path, options);
			return set;
		}, {});
	});

	// console.log(JSON.stringify(output, null, 2))

	_fs2['default'].writeFileSync(options.output, JSON.stringify(output));
}

module.exports = exports['default'];
//# sourceMappingURL=write stats.js.map